@@ -39,15 +39,6 @@ has isEnable => (is => 'rw', required => 0, default => 0);
 # Expect 对象
 has expect => (is => 'rw', isa => 'Expect');
 
-# 待执行的命令列表
-has commands => (
-  is       => 'rw',
-  isa      => 'ArrayRef[Str]',
-  required => 0,
-  traits   => ['Array'],
-  handles  => {addCommand => 'push', pushCommand => 'unshift'}
-);
-
 # 配置获取方法，需在具体设备类中实现
 requires 'getConfig';
 requires 'waitfor';
@@ -93,13 +84,13 @@ sub login {
     if ($@ =~ /RSA modulus too small/) {
       eval { $self->connect('-v -1 -c des '); };
       if (defined $@) {
-        return {success => 0, comment => 'RSA 模数太小', reason => $@};
+        return {success => 0, failCommand => 'RSA 模数太小', reason => $@};
       }
     }
     elsif ($@ =~ /Selected cipher type <unknown> not supported by server/i) {
       eval { $self->connect('-c des '); };
       if (defined $@) {
-        return {success => 0, comment => '服务器不支持所选密码类型 ', reason => $@};
+        return {success => 0, failCommand => '服务器不支持所选密码类型 ', reason => $@};
       }
     }
     elsif ($@ =~ /Connection refused/i) {
@@ -108,18 +99,18 @@ sub login {
         $self->connect();
       };
       if (defined $@) {
-        return {success => 0, comment => '尝试 telnet 登录期间捕捉异常', reason => $@};
+        return {success => 0, failCommand => '尝试 telnet 登录期间捕捉异常', reason => $@};
       }
     }
     elsif ($@ =~ /IDENTIFICATION CHANGED/i) {
       `/usr/bin/ssh-keygen -R $self->{host}`;
       eval { $self->connect(); };
       if (defined $@) {
-        return {success => 0, comment => '设备身份识别已更改', reason => $@};
+        return {success => 0, failCommand => '设备身份识别已更改', reason => $@};
       }
     }
     else {
-      return {success => 0, comment => '尝试重新登录设备期间捕捉到异常', reason => $@};
+      return {success => 0, failCommand => '尝试重新登录设备期间捕捉到异常', reason => $@};
     }
   }
 
@@ -188,7 +179,7 @@ sub send {
 
 # 生成 Expect->new 对象
 sub buildExpect {
-  my $self = shift;
+  shift;
 
   # 实例化 Expect 函数对象
   my $exp = Expect->new();
@@ -246,7 +237,7 @@ sub buildConnector {
 }
 
 sub enable {
-  my $self = shift;
+  shift;
   return 0;
 }
 
