@@ -148,7 +148,7 @@ sub enable {
 
   # 如果发生异常，返回失败
   if (defined $ret[1]) {
-    return {success => 0, comment => '无法切换到特权模式', reason => $ret[3]};
+    return {success => 0, failCommand => '无法切换到特权模式', reason => $ret[3]};
   }
 
   @ret = $exp->expect(
@@ -159,7 +159,7 @@ sub enable {
 
   # 如果发生异常，返回失败
   if (defined $ret[1]) {
-    return {success => 0, comment => '无法切换到特权模式', reason => $ret[3]};
+    return {success => 0, failCommand => '无法切换到特权模式', reason => $ret[3]};
   }
 
   return {success => 1};
